# ###################################################
# Copyright (C) 2013 The Unknown Horizons Team
# team@unknown-horizons.org
# This file is part of Unknown Horizons.
#
# Unknown Horizons is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# ###################################################

"""Modules for gui/ingamegui"""

from playerdataselection import PlayerDataSelection
from aidataselection import AIDataSelection
from singleplayermenu import SingleplayerMenu
from multiplayermenu import MultiplayerMenu
from help import HelpDialog
from select_savegame import SelectSavegameDialog
from loadingscreen import LoadingScreen
from pausemenu import PauseMenu
from settings import SettingsDialog
